==> react-cosmos-1.0.1.tgz: package/lib/index.js <==
'use strict';

var _reactQuerystringRouter = require('react-querystring-router');

var _reactQuerystringRouter2 = _interopRequireDefault(_reactQuerystringRouter);

var _reactComponentPlayground = require('react-component-playground');

var _reactComponentPlayground2 = _interopRequireDefault(_reactComponentPlayground);

var _loadModules = require('./load-modules');

var _linkedList = require('./linked-list');

var _linkedList2 = _interopRequireDefault(_linkedList);

var _PreviewLoader = require('./proxies/PreviewLoader');

var _PreviewLoader2 = _interopRequireDefault(_PreviewLoader);

var _StateProxy = require('./proxies/StateProxy');

var _StateProxy2 = _interopRequireDefault(_StateProxy);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var getTitleForFixture = function getTitleForFixture(params) {
  var title = 'React Cosmos';

  // Set document title to the name of the selected fixture
  if (params.component && params.fixture) {
    title = params.component + ':' + params.fixture + ' \u2013 ' + title;
  }

  return title;
};

module.exports = function (_ref) {
  var proxies = _ref.proxies;
  var components = _ref.components;
  var fixtures = _ref.fixtures;
  var containerQuerySelector = _ref.containerQuerySelector;
  var containerClassName = _ref.containerClassName;

  var firstProxy = (0, _linkedList2.default)([].concat(_toConsumableArray(proxies), [
  // Loaded by default in all configs
  (0, _StateProxy2.default)(),
  // The final proxy in the chain simply renders the preview component
  _PreviewLoader2.default]));

  var container = containerQuerySelector ? document.querySelector(containerQuerySelector) : document.body.appendChild(document.createElement('div'));

  return new _reactQuerystringRouter2.default.Router({
    container: container,
    defaultProps: {
      firstProxy: firstProxy,
      components: (0, _loadModules.loadComponents)(components),
      fixtures: (0, _loadModules.loadFixtures)(fixtures),
      containerClassName: containerClassName
    },
    getComponentClass: function getComponentClass() {
      return _reactComponentPlayground2.default;
    },
    onChange: function onChange(params) {
      document.title = getTitleForFixture(params);
    }
  });
};

==> react-cosmos-1.1.0.tgz: package/lib/index.js <==
'use strict';

var _reactQuerystringRouter = require('react-querystring-router');

var _reactQuerystringRouter2 = _interopRequireDefault(_reactQuerystringRouter);

var _reactComponentPlayground = require('react-component-playground');

var _reactComponentPlayground2 = _interopRequireDefault(_reactComponentPlayground);

var _loadModules = require('./load-modules');

var _linkedList = require('./linked-list');

var _linkedList2 = _interopRequireDefault(_linkedList);

var _PreviewLoader = require('./proxies/PreviewLoader');

var _PreviewLoader2 = _interopRequireDefault(_PreviewLoader);

var _StateProxy = require('./proxies/StateProxy');

var _StateProxy2 = _interopRequireDefault(_StateProxy);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var getTitleForFixture = function getTitleForFixture(params) {
  var title = 'React Cosmos';

  // Set document title to the name of the selected fixture
  if (params.component && params.fixture) {
    title = params.component + ':' + params.fixture + ' \u2013 ' + title;
  }

  return title;
};

module.exports = function (_ref) {
  var proxies = _ref.proxies,
      components = _ref.components,
      fixtures = _ref.fixtures,
      containerQuerySelector = _ref.containerQuerySelector,
      containerClassName = _ref.containerClassName;

  var firstProxy = (0, _linkedList2.default)([].concat(_toConsumableArray(proxies), [
  // Loaded by default in all configs
  (0, _StateProxy2.default)(),
  // The final proxy in the chain simply renders the preview component
  _PreviewLoader2.default]));

  var container = containerQuerySelector ? document.querySelector(containerQuerySelector) : document.body.appendChild(document.createElement('div'));

  return new _reactQuerystringRouter2.default.Router({
    container: container,
    defaultProps: {
      firstProxy: firstProxy,
      components: (0, _loadModules.loadComponents)(components),
      fixtures: (0, _loadModules.loadFixtures)(fixtures),
      containerClassName: containerClassName
    },
    getComponentClass: function getComponentClass() {
      return _reactComponentPlayground2.default;
    },
    onChange: function onChange(params) {
      document.title = getTitleForFixture(params);
    }
  });
};
